<?php
/**
 * Handler for [etl_guten_block] shortcode
 *
 * @param $atts
 *
 * @return string
 */
function etl_block_handler($atts)
{
	$atts = shortcode_atts([
		'heading' => __('Everest Tab-Lite Title'),
		'heading_tag' => 'h2',
		'etl_id' => '',
	], $atts, 'etl_guten_block');

	return etl_block_renderer($atts[ 'heading' ],$atts[ 'heading_tag' ],$atts[ 'etl_id' ]);
}

add_shortcode('etl_guten_block', 'etl_block_handler');

/**
 * Handler for post title block
 * @param $atts
 *
 * @return string
 */
function etl_block_render_handler($atts)
{
	return etl_block_renderer($atts[ 'heading' ],$atts[ 'heading_tag' ],$atts[ 'etl_id' ]);
}

/**
 * Output the post title wrapped in a heading
 *
 * @param int $etl_id The post ID
 * @param string $heading Allows : h2,h3,h4 only
 *
 * @return string
 */
function etl_block_renderer($heading,$heading_tag,$etl_id)
{	
	$ret = '';
	if(!empty($heading)){
		$ret .= "<$heading_tag>$heading</$heading_tag>";
	}
	
	if($etl_id!=null){
		$sht = "[etabs slug='$etl_id']";
		$title = do_shortcode($sht);
		$ret .= "$title";
	}
	return $ret;
}

/**
 * Register block
 */
add_action('init', function () {
	// Skip block registration if Gutenberg is not enabled/merged.
	if (!function_exists('register_block_type')) {
		return;
	}
	$dir = dirname(__FILE__);

	wp_enqueue_style( 'et-frontend-style', ETABLite_CSS_DIR . '/et-style.css', false, ETABLite_VERSION );
	wp_enqueue_style( 'etl-block-editor', plugins_url('etl-block.css', __FILE__), false, ETABLite_VERSION );
	wp_enqueue_style('et-frontend-style', ETABLite_CSS_DIR . 'et-style.css', false, ETABLite_VERSION);
	wp_enqueue_style('et_fontawesome_style', ETABLite_CSS_DIR . 'available_icons/font-awesome/font-awesome.min.css',false,ETABLite_VERSION);
	wp_enqueue_style('et-animate-style', ETABLite_CSS_DIR . 'animate.css', false, ETABLite_VERSION);
	wp_enqueue_script('et-frontend-script', ETABLite_FRONTEND_JS_DIR . 'et-frontend-script.js', array('jquery'), ETABLite_VERSION);

	$index_js = 'etl-block.js';
	wp_register_script(
		'etl-block-script',
		plugins_url($index_js, __FILE__),
		array(
			'wp-blocks',
			'wp-i18n',
			'wp-element',
			'wp-components',
			'wp-editor'
		),
		filemtime("$dir/$index_js")
	);

	$etl_logos_array = get_etl_logos();
	wp_localize_script( 'etl-block-script', 'ETL_logos_array', $etl_logos_array);

	register_block_type('etl-display-block/etl-widget', array(
		'editor_script' => 'etl-block-script',
		'render_callback' => 'etl_block_render_handler',
		'attributes' => [			
			'heading' => [
				'type' => 'string',
				'default' => __('Everest Tab-Lite Title')
			],
			'heading_tag' => [
				'type' => 'string',
				'default' => 'h2'
			],
			'etl_id' => [
				'type' => 'string',
				'default' => ''
			],
		]
	));
});

function get_etl_logos(){
	$args = array('post_type'=>'everest_tab',
		'post_status'=>'publish',
		'posts_per_page'=>'25'
	);
    // The Query
	$the_query = new WP_Query( $args );

	$everest_tab = array(array('value'=>'0','label'=>__('Select Tab')));

    // The Loop
	if ( $the_query->have_posts() ) {
		while($the_query->have_posts()){
			$the_query->the_post();
			global $post;
			$everest_tab[] = array('value'=>$post->post_name, 'label'=> get_the_title());
		}
	}

	return $everest_tab;
}